# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring
import sys

from afasi.cli import app

if __name__ == '__main__':
    sys.exit(app(prog_name='afasi'))  # pragma: no cover
